@@ -18,7 +18,7 @@ public class ReactiveGreetingService {
     public Multi<String> greetings(int count, String name) {
         return Multi.createFrom().ticks().every(Duration.ofSeconds(1))
                 .onItem().transform(n -> String.format("hello %s - %d", name, n))
-                .transform().byTakingFirstItems(count);
+                .select().first(count);
 
     }
 
